@@ -82,6 +82,7 @@ TESTFN = os.path.join(os.getcwd(), "$testfile")
 TESTFN_UNICODE = TESTFN + "ƒőő"
 TESTFILE_PREFIX = 'psutil-test-suite-'
 TOX = os.getenv('TOX') or '' in ('1', 'true')
+PYPY = '__pypy__' in sys.builtin_module_names
 if not PY3:
     try:
         TESTFN_UNICODE = unicode(TESTFN_UNICODE, sys.getfilesystemencoding())
@@ -344,8 +345,10 @@ def reap_children(search_all=False):
     _subprocesses_started = set(alive)
 
 
-def check_ip_address(addr, family):
-    """Attempts to check IP address's validity."""
+def check_net_address(addr, family):
+    """Check a net address validity. Supported families are IPv4,
+    IPv6 and MAC addresses.
+    """
     if enum and PY3:
         assert isinstance(family, enum.IntEnum), family
     if family == AF_INET:
@@ -392,7 +395,7 @@ def check_connection_ntuple(conn):
             ip, port = addr
             assert isinstance(port, int), port
             assert 0 <= port <= 65535, port
-            check_ip_address(ip, conn.family)
+            check_net_address(ip, conn.family)
         elif conn.family == AF_UNIX:
             assert isinstance(addr, (str, None)), addr
         else:
@@ -486,9 +489,9 @@ def retry_before_failing(ntimes=None):
             for x in range(times):
                 try:
                     return fun(*args, **kwargs)
-                except AssertionError:
-                    pass
-            raise
+                except AssertionError as _:
+                    err = _
+            raise err
         return wrapper
     return decorator
 
